@@ -32,10 +32,7 @@ KmagApp *kmagapp;
 int main(int argc, char *argv[])
 {
   QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-  app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-  KLocalizedString::setApplicationDomain("kmag");
+  KLocalizedString::setApplicationDomain(QByteArrayLiteral("kmag"));
 
   // about the application
   KAboutData aboutData(QStringLiteral("kmag"), i18n("KMagnifier"), QStringLiteral(KMAG_VERSION_STRING),
